@@ -1,7 +1,6 @@
 import urllib
 import urlparse
 
-from django import forms
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse
 from django.utils.translation import ugettext_lazy as _
@@ -65,8 +64,9 @@ class JIRAPlugin(IssuePlugin):
 
     def create_issue(self, request, group, form_data, **kwargs):
         """
-        Since this is called wrapped in a try/catch on ValidationError to display
-        an end user error, that's what I'll throw when JIRA doesn't like it.
+        Form validation errors recognized server-side raise ValidationErrors,
+        but when validation errors occur in JIRA they are simply attached to
+        the form.
         """
         jira_client = self.get_jira_client(group.project)
         issue_response = jira_client.create_issue(form_data)
@@ -118,8 +118,11 @@ class JIRAPlugin(IssuePlugin):
         if GroupMeta.objects.get_value(group, '%s:tid' % self.get_conf_key(), None):
             return None
 
+        #######################################################################
+        # Auto-complete handler
         if request.GET.get("user_autocomplete"):
             return self.handle_autocomplete(request, group, **kwargs)
+        #######################################################################
 
         prefix = self.get_conf_key()
         event = group.get_latest_event()
@@ -136,22 +139,18 @@ class JIRAPlugin(IssuePlugin):
         if request.POST and request.POST.get("changing_issuetype") == "0":
         ########################################################################
             if form.is_valid():
-                try:
-                    issue_id, error = self.create_issue(
-                        group=group,
-                        form_data=form.cleaned_data,
-                        request=request,
-                    )
-                    if error:
-                        form.errors.update(error)
-
-                except forms.ValidationError, e:
-                    form.errors['__all__'] = [u'Error creating issue: %s' % e]
+                issue_id, error = self.create_issue(
+                    group=group,
+                    form_data=form.cleaned_data,
+                    request=request,
+                )
+                if error:
+                    form.errors.update(error)
 
             if form.is_valid():
                 GroupMeta.objects.set_value(group, '%s:tid' % prefix, issue_id)
 
-                return self.redirect(reverse('sentry-group', args=[group.project_id, group.pk]))
+                return self.redirect(reverse('sentry-group', args=[group.team.slug, group.project_id, group.pk]))
         else:
             for name, field in form.fields.items():
                 form.errors[name] = form.error_class()
